Presentación — titulo...

# Presentación

Patín es una herramienta para aprender a programar computadoras de manera simple y divertida.

En patín, vas a encontrar ideas, programas y cursos para crear proyectos completos.

Vas a poder hacer videojuegos, programas gráficos con ventanas e incluso sitios webs dinámicos.

El lenguaje de programación que se verá en patín se llama python. Este lenguaje es muy fácil de aprender y tiene muchísimo potencial, de hecho se usa profesionalmente en muchos sistemas.